# DocumenterCitations.jl

[![Version](https://juliahub.com/docs/DocumenterCitations/version.svg)](https://juliahub.com/ui/Packages/DocumenterCitations/B0owD)
[![Stable](https://img.shields.io/badge/docs-stable-blue.svg)](https://juliadocs.github.io/DocumenterCitations.jl/)
[![Dev](https://img.shields.io/badge/docs-dev-blue.svg)](https://juliadocs.github.io/DocumenterCitations.jl/dev)
[![Build Status](https://github.com/JuliaDocs/DocumenterCitations.jl/workflows/CI/badge.svg)](https://github.com/JuliaDocs/DocumenterCitations.jl/actions)
[![PkgEval](https://juliahub.com/docs/General/DocumenterCitations/stable/pkgeval.svg)](https://juliaci.github.io/NanosoldierReports/pkgeval_badges/report.html)
[![Coverage](https://codecov.io/gh/JuliaDocs/DocumenterCitations.jl/branch/master/graph/badge.svg)](https://codecov.io/gh/JuliaDocs/DocumenterCitations.jl)


[DocumenterCitations.jl](https://github.com/JuliaDocs/DocumenterCitations.jl#readme) uses [Bibliography.jl](https://github.com/Humans-of-Julia/Bibliography.jl) to add support for BibTeX citations in documentation pages generated by [Documenter.jl](https://github.com/JuliaDocs/Documenter.jl).

By default, [DocumenterCitations.jl](https://github.com/JuliaDocs/DocumenterCitations.jl#readme) uses a numeric citation style common in the natural sciences, see e.g. the [journals of the American Physical Society](https://journals.aps.org), and the [REVTeX author's guide](https://www.ctan.org/tex-archive/macros/latex/contrib/revtex/auguide).  Citations are shown in-line, as a number enclosed in square brackets, e.g., "Optimal control is a cornerstone in the development of quantum technologies [[1](#screenshot)]."


<img id="screenshot" src="docs/src/assets/references.png" alt="Rendered bibliography of two references, [1] and [2]" width="830px">

Alternatively, author-year and alphabetic citations styles are available, see the [Citation Style Gallery](https://juliadocs.github.io/DocumenterCitations.jl/dev/gallery/). Prior to version 1.0, the author-year style was the default, see [NEWS.md](NEWS.md). It is possible to define custom styles.


## Installation

The `DocumenterCitations` package can be installed with [Pkg](https://pkgdocs.julialang.org/v1/) as

~~~
pkg> add DocumenterCitations
~~~

In most cases, you will just want to have `DocumenterCitations` in the project that builds your documentation (e.g. [`test/Project.toml`](https://github.com/JuliaDocs/DocumenterCitations.jl/blob/master/test/Project.toml)). Thus, you can also simply add

```
DocumenterCitations = "daee34ce-89f3-4625-b898-19384cb65244"
```

to the `[deps]` section of the relevant `Project.toml` file.


## Usage

*   Place a BibTeX [`refs.bib`](https://github.com/JuliaDocs/DocumenterCitations.jl/blob/master/docs/src/refs.bib) file in the `docs/src` folder of your project.  Then, in [`docs/make.jl`](https://github.com/JuliaDocs/DocumenterCitations.jl/blob/master/docs/make.jl), instantiate the `CitationBibliography` plugin with the path to the `.bib` file. Assuming `Documenter >= 1.0`, pass the plugin object to [`makedocs`](https://documenter.juliadocs.org/stable/lib/public/#Documenter.makedocs) as element of the `plugins` keyword argument:

    ```julia
    using DocumenterCitations

    bib = CitationBibliography(joinpath(@__DIR__, "src", "refs.bib"))
    makedocs(; plugins=[bib], ...)
    ```

    In older versions of [Documenter.jl](https://github.com/JuliaDocs/Documenter.jl), `bib` had to be passed as a positional argument to `makedocs`.

*   Optional, but recommended: [add CSS to properly format the bibliography](https://juliadocs.github.io/DocumenterCitations.jl/dev/styling/)

*   Somewhere in your documentation include a markdown block

    ~~~markdown
    ```@bibliography
    ```
    ~~~

    that will expand into a bibliography for all citations in the documentation.

*   Anywhere in the documentation or in docstrings, insert citations as, e.g., `[GoerzQ2022](@cite)`, which will be rendered as "[[2](#screenshot)]" and link to the full reference in the bibliography.

See the [documentation](https://juliadocs.github.io/DocumenterCitations.jl) for additional information.

## Documentation

The documentation of `DocumenterCitations.jl` is available at <https://juliadocs.github.io/DocumenterCitations.jl>. In addition to documenting the usage of the package, it also serves as its showcase.
